# eric7.DocumentationTools

Package implementing the source code documentation tools.

### Modules

APIGenerator | Module implementing the builtin API generator.
Config | Module defining different default values for the documentation tools package.
IndexGenerator | Module implementing the index generator for the builtin documentation generator.
ModuleDocumentor | Module implementing the builtin documentation generator.
QtHelpGenerator | Module implementing the QtHelp generator for the builtin documentation generator.
TemplatesListsStyleCSS | Module implementing templates for the documentation generator (lists style).